# coding: utf-8

"""
    Rightfoot Student Loan Repayment

    This API provides student loan repayment. You can find out more about
    Rightfoot at [docs.rightfoot.com](https://docs.rightfoot.com).

    OpenAPI spec version: 1.1.0
    Contact: engineering@rightfoot.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from setuptools import setup, find_packages  # noqa: H301
from os import path

NAME = "rightfoot"
VERSION = "1.2.0a1"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

def read_readme():
  """Read the contents of the README file."""
  this_directory = path.abspath(path.dirname(__file__))
  with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
      return f.read()


setup(
    name=NAME,
    version=VERSION,
    description="Python API client for Rightfoot student debt repayment.",
    author_email="engineering@rightfoot.com",
    url="https://rightfoot.com",
    keywords=[
        "Rightfoot Student Loan Repayment",
        "rightfoot",
        "student",
        "debt",
        "payments",
    ],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description=read_readme(),
    long_description_content_type="text/markdown"
)
